==> v1.4.zip: mk0.software.bildduplikate/Mk0.Software.Bildduplikate/Main.Designer.cs <==
﻿
namespace Mk0.Software.Bildduplikate
{
    partial class Main
    {
        /// <summary>
        /// Erforderliche Designervariable.
        /// </summary>
        private System.ComponentModel.IContainer components = null;

        /// <summary>
        /// Verwendete Ressourcen bereinigen.
        /// </summary>
        /// <param name="disposing">True, wenn verwaltete Ressourcen gelöscht werden sollen; andernfalls False.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }
            base.Dispose(disposing);
        }

        #region Vom Windows Form-Designer generierter Code

        /// <summary>
        /// Erforderliche Methode für die Designerunterstützung.
        /// Der Inhalt der Methode darf nicht mit dem Code-Editor geändert werden.
        /// </summary>
        private void InitializeComponent()
        {
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Main));
            this.buttonCSV = new System.Windows.Forms.Button();
            this.buttonDel1 = new System.Windows.Forms.Button();
            this.buttonDel2 = new System.Windows.Forms.Button();
            this.pictureBox1 = new System.Windows.Forms.PictureBox();
            this.pictureBox2 = new System.Windows.Forms.PictureBox();
            this.buttonKeinDuplikat = new System.Windows.Forms.Button();
            this.openFileDialog1 = new System.Windows.Forms.OpenFileDialog();
            this.splitContainer1 = new System.Windows.Forms.SplitContainer();
            this.label3 = new System.Windows.Forms.Label();
            this.buttonReload = new System.Windows.Forms.Button();
            this.splitContainer2 = new System.Windows.Forms.SplitContainer();
            this.textBoxDesc1 = new System.Windows.Forms.TextBox();
            this.textBoxDesc2 = new System.Windows.Forms.TextBox();
            this.buttonAPISetting = new System.Windows.Forms.Button();
            this.buttonAPILoad = new System.Windows.Forms.Button();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox2)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.splitContainer1)).BeginInit();
            this.splitContainer1.Panel1.SuspendLayout();
            this.splitContainer1.Panel2.SuspendLayout();
            this.splitContainer1.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.splitContainer2)).BeginInit();
            this.splitContainer2.Panel1.SuspendLayout();
            this.splitContainer2.Panel2.SuspendLayout();
            this.splitContainer2.SuspendLayout();
            this.SuspendLayout();
            // 
            // buttonCSV
            // 
            this.buttonCSV.Location = new System.Drawing.Point(12, 12);
            this.buttonCSV.Name = "buttonCSV";
            this.buttonCSV.Size = new System.Drawing.Size(75, 23);
            this.buttonCSV.TabIndex = 0;
            this.buttonCSV.Text = "CSV";
            this.buttonCSV.UseVisualStyleBackColor = true;
            this.buttonCSV.Click += new System.EventHandler(this.ButtonCSV_Click);
            // 
            // buttonDel1
            // 
            this.buttonDel1.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
            this.buttonDel1.Location = new System.Drawing.Point(313, 3);
            this.buttonDel1.Name = "buttonDel1";
            this.buttonDel1.Size = new System.Drawing.Size(75, 23);
            this.buttonDel1.TabIndex = 2;
            this.buttonDel1.Text = "LÖSCHEN";
            this.buttonDel1.UseVisualStyleBackColor = true;
            this.buttonDel1.Visible = false;
            this.buttonDel1.Click += new System.EventHandler(this.ButtonDel1_Click);
            // 
            // buttonDel2
            // 
            this.buttonDel2.Location = new System.Drawing.Point(0, 3);
            this.buttonDel2.Name = "buttonDel2";
            this.buttonDel2.Size = new System.Drawing.Size(75, 23);
            this.buttonDel2.TabIndex = 3;
            this.buttonDel2.Text = "LÖSCHEN";
            this.buttonDel2.UseVisualStyleBackColor = true;
            this.buttonDel2.Visible = false;
            this.buttonDel2.Click += new System.EventHandler(this.ButtonDel2_Click);
            // 
            // pictureBox1
            // 
            this.pictureBox1.BackColor = System.Drawing.SystemColors.Control;
            this.pictureBox1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.pictureBox1.Location = new System.Drawing.Point(0, 0);
            this.pictureBox1.Name = "pictureBox1";
            this.pictureBox1.Size = new System.Drawing.Size(388, 315);
            this.pictureBox1.SizeMode = System.Windows.Forms.PictureBoxSizeMode.Zoom;
            this.pictureBox1.TabIndex = 6;
            this.pictureBox1.TabStop = false;
            this.pictureBox1.Visible = false;
            this.pictureBox1.Click += new System.EventHandler(this.ButtonDel1_Click);
            // 
            // pictureBox2
            // 
            this.pictureBox2.BackColor = System.Drawing.SystemColors.Control;
            this.pictureBox2.Dock = System.Windows.Forms.DockStyle.Fill;
            this.pictureBox2.Location = new System.Drawing.Point(0, 0);
            this.pictureBox2.Name = "pictureBox2";
            this.pictureBox2.Size = new System.Drawing.Size(384, 315);
            this.pictureBox2.SizeMode = System.Windows.Forms.PictureBoxSizeMode.Zoom;
            this.pictureBox2.TabIndex = 7;
            this.pictureBox2.TabStop = false;
            this.pictureBox2.Visible = false;
            this.pictureBox2.Click += new System.EventHandler(this.ButtonDel2_Click);
            // 
            // buttonKeinDuplikat
            // 
            this.buttonKeinDuplikat.Anchor = System.Windows.Forms.AnchorStyles.Top;
            this.buttonKeinDuplikat.Location = new System.Drawing.Point(280, 12);
            this.buttonKeinDuplikat.Name = "buttonKeinDuplikat";
            this.buttonKeinDuplikat.Size = new System.Drawing.Size(217, 23);
            this.buttonKeinDuplikat.TabIndex = 8;
            this.buttonKeinDuplikat.Text = "KEIN DUPLIKAT";
            this.buttonKeinDuplikat.UseVisualStyleBackColor = true;
            this.buttonKeinDuplikat.Visible = false;
            this.buttonKeinDuplikat.Click += new System.EventHandler(this.ButtonKeinDuplikat_Click);
            // 
            // splitContainer1
            // 
            this.splitContainer1.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
            | System.Windows.Forms.AnchorStyles.Left) 
            | System.Windows.Forms.AnchorStyles.Right)));
            this.splitContainer1.Enabled = false;
            this.splitContainer1.Location = new System.Drawing.Point(12, 41);
            this.splitContainer1.Name = "splitContainer1";
            // 
            // splitContainer1.Panel1
            // 
            this.splitContainer1.Panel1.Controls.Add(this.pictureBox1);
            // 
            // splitContainer1.Panel2
            // 
            this.splitContainer1.Panel2.Controls.Add(this.pictureBox2);
            this.splitContainer1.Size = new System.Drawing.Size(776, 315);
            this.splitContainer1.SplitterDistance = 388;
            this.splitContainer1.TabIndex = 9;
            this.splitContainer1.KeyDown += new System.Windows.Forms.KeyEventHandler(this.Form1_KeyDown);
            // 
            // label3
            // 
            this.label3.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
            this.label3.Location = new System.Drawing.Point(598, 17);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(190, 23);
            this.label3.TabIndex = 10;
            this.label3.Text = "label3";
            this.label3.TextAlign = System.Drawing.ContentAlignment.TopRight;
            this.label3.Visible = false;
            // 
            // buttonReload
            // 
            this.buttonReload.Location = new System.Drawing.Point(93, 12);
            this.buttonReload.Name = "buttonReload";
            this.buttonReload.Size = new System.Drawing.Size(75, 23);
            this.buttonReload.TabIndex = 11;
            this.buttonReload.Text = "reload";
            this.buttonReload.UseVisualStyleBackColor = true;
            this.buttonReload.Click += new System.EventHandler(this.ButtonReload_Click);
            // 
            // splitContainer2
            // 
            this.splitContainer2.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left) 
            | System.Windows.Forms.AnchorStyles.Right)));
            this.splitContainer2.Location = new System.Drawing.Point(12, 362);
            this.splitContainer2.Name = "splitContainer2";
            // 
            // splitContainer2.Panel1
            // 
            this.splitContainer2.Panel1.Controls.Add(this.textBoxDesc1);
            this.splitContainer2.Panel1.Controls.Add(this.buttonDel1);
            // 
            // splitContainer2.Panel2
            // 
            this.splitContainer2.Panel2.Controls.Add(this.textBoxDesc2);
            this.splitContainer2.Panel2.Controls.Add(this.buttonDel2);
            this.splitContainer2.Size = new System.Drawing.Size(775, 81);
            this.splitContainer2.SplitterDistance = 388;
            this.splitContainer2.TabIndex = 12;
            this.splitContainer2.KeyDown += new System.Windows.Forms.KeyEventHandler(this.Form1_KeyDown);
            // 
            // textBoxDesc1
            // 
            this.textBoxDesc1.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
            this.textBoxDesc1.BackColor = System.Drawing.SystemColors.Control;
            this.textBoxDesc1.Location = new System.Drawing.Point(-139, 32);
            this.textBoxDesc1.Multiline = true;
            this.textBoxDesc1.Name = "textBoxDesc1";
            this.textBoxDesc1.Size = new System.Drawing.Size(524, 49);
            this.textBoxDesc1.TabIndex = 3;
            this.textBoxDesc1.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.textBoxDesc1.Visible = false;
            // 
            // textBoxDesc2
            // 
            this.textBoxDesc2.BackColor = System.Drawing.SystemColors.Control;
            this.textBoxDesc2.BorderStyle = System.Windows.Forms.BorderStyle.None;
            this.textBoxDesc2.Location = new System.Drawing.Point(3, 32);
            this.textBoxDesc2.Multiline = true;
            this.textBoxDesc2.Name = "textBoxDesc2";
            this.textBoxDesc2.Size = new System.Drawing.Size(592, 44);
            this.textBoxDesc2.TabIndex = 4;
            this.textBoxDesc2.Visible = false;
            // 
            // buttonAPISetting
            // 
            this.buttonAPISetting.Location = new System.Drawing.Point(174, 12);
            this.buttonAPISetting.Name = "buttonAPISetting";
            this.buttonAPISetting.Size = new System.Drawing.Size(75, 23);
            this.buttonAPISetting.TabIndex = 13;
            this.buttonAPISetting.Text = "API Setting";
            this.buttonAPISetting.UseVisualStyleBackColor = true;
            this.buttonAPISetting.Click += new System.EventHandler(this.ButtonAPI_Click);
            // 
            // buttonAPILoad
            // 
            this.buttonAPILoad.Location = new System.Drawing.Point(255, 12);
            this.buttonAPILoad.Name = "buttonAPILoad";
            this.buttonAPILoad.Size = new System.Drawing.Size(75, 23);
            this.buttonAPILoad.TabIndex = 14;
            this.buttonAPILoad.Text = "Load API";
            this.buttonAPILoad.UseVisualStyleBackColor = true;
            this.buttonAPILoad.Click += new System.EventHandler(this.ButtonAPILoad_Click);
            // 
            // Main
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.ClientSize = new System.Drawing.Size(800, 450);
            this.Controls.Add(this.buttonAPILoad);
            this.Controls.Add(this.buttonAPISetting);
            this.Controls.Add(this.splitContainer2);
            this.Controls.Add(this.buttonReload);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.splitContainer1);
            this.Controls.Add(this.buttonKeinDuplikat);
            this.Controls.Add(this.buttonCSV);
            this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
            this.KeyPreview = true;
            this.Name = "Main";
            this.Text = "Bildduplikate v1.4 by kmpr.at";
            this.KeyDown += new System.Windows.Forms.KeyEventHandler(this.Form1_KeyDown);
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox2)).EndInit();
            this.splitContainer1.Panel1.ResumeLayout(false);
            this.splitContainer1.Panel2.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.splitContainer1)).EndInit();
            this.splitContainer1.ResumeLayout(false);
            this.splitContainer2.Panel1.ResumeLayout(false);
            this.splitContainer2.Panel1.PerformLayout();
            this.splitContainer2.Panel2.ResumeLayout(false);
            this.splitContainer2.Panel2.PerformLayout();
            ((System.ComponentModel.ISupportInitialize)(this.splitContainer2)).EndInit();
            this.splitContainer2.ResumeLayout(false);
            this.ResumeLayout(false);

        }

        #endregion

        private System.Windows.Forms.Button buttonCSV;
        private System.Windows.Forms.Button buttonDel1;
        private System.Windows.Forms.Button buttonDel2;
        private System.Windows.Forms.PictureBox pictureBox1;
        private System.Windows.Forms.PictureBox pictureBox2;
        private System.Windows.Forms.Button buttonKeinDuplikat;
        private System.Windows.Forms.OpenFileDialog openFileDialog1;
        private System.Windows.Forms.SplitContainer splitContainer1;
        private System.Windows.Forms.Label label3;
        private System.Windows.Forms.Button buttonReload;
        private System.Windows.Forms.SplitContainer splitContainer2;
        private System.Windows.Forms.TextBox textBoxDesc1;
        private System.Windows.Forms.TextBox textBoxDesc2;
        private System.Windows.Forms.Button buttonAPISetting;
        private System.Windows.Forms.Button buttonAPILoad;
    }
}

==> v1.5.zip: mk0.software.bildduplikate/Mk0.Software.Bildduplikate/Main.Designer.cs <==
﻿
namespace Mk0.Software.Bildduplikate
{
    partial class Main
    {
        /// <summary>
        /// Erforderliche Designervariable.
        /// </summary>
        private System.ComponentModel.IContainer components = null;

        /// <summary>
        /// Verwendete Ressourcen bereinigen.
        /// </summary>
        /// <param name="disposing">True, wenn verwaltete Ressourcen gelöscht werden sollen; andernfalls False.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }
            base.Dispose(disposing);
        }

        #region Vom Windows Form-Designer generierter Code

        /// <summary>
        /// Erforderliche Methode für die Designerunterstützung.
        /// Der Inhalt der Methode darf nicht mit dem Code-Editor geändert werden.
        /// </summary>
        private void InitializeComponent()
        {
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Main));
            this.buttonCSV = new System.Windows.Forms.Button();
            this.buttonDel1 = new System.Windows.Forms.Button();
            this.buttonDel2 = new System.Windows.Forms.Button();
            this.pictureBox1 = new System.Windows.Forms.PictureBox();
            this.pictureBox2 = new System.Windows.Forms.PictureBox();
            this.buttonKeinDuplikat = new System.Windows.Forms.Button();
            this.openFileDialog1 = new System.Windows.Forms.OpenFileDialog();
            this.splitContainer1 = new System.Windows.Forms.SplitContainer();
            this.label3 = new System.Windows.Forms.Label();
            this.buttonReload = new System.Windows.Forms.Button();
            this.splitContainer2 = new System.Windows.Forms.SplitContainer();
            this.buttonAPISetting = new System.Windows.Forms.Button();
            this.buttonAPILoad = new System.Windows.Forms.Button();
            this.richTextBoxDesc1 = new System.Windows.Forms.RichTextBox();
            this.richTextBoxDesc2 = new System.Windows.Forms.RichTextBox();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox2)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.splitContainer1)).BeginInit();
            this.splitContainer1.Panel1.SuspendLayout();
            this.splitContainer1.Panel2.SuspendLayout();
            this.splitContainer1.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.splitContainer2)).BeginInit();
            this.splitContainer2.Panel1.SuspendLayout();
            this.splitContainer2.Panel2.SuspendLayout();
            this.splitContainer2.SuspendLayout();
            this.SuspendLayout();
            // 
            // buttonCSV
            // 
            this.buttonCSV.Location = new System.Drawing.Point(12, 12);
            this.buttonCSV.Name = "buttonCSV";
            this.buttonCSV.Size = new System.Drawing.Size(75, 23);
            this.buttonCSV.TabIndex = 0;
            this.buttonCSV.Text = "CSV";
            this.buttonCSV.UseVisualStyleBackColor = true;
            this.buttonCSV.Click += new System.EventHandler(this.ButtonCSV_Click);
            // 
            // buttonDel1
            // 
            this.buttonDel1.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
            this.buttonDel1.Location = new System.Drawing.Point(405, 3);
            this.buttonDel1.Name = "buttonDel1";
            this.buttonDel1.Size = new System.Drawing.Size(75, 23);
            this.buttonDel1.TabIndex = 2;
            this.buttonDel1.Text = "LÖSCHEN";
            this.buttonDel1.UseVisualStyleBackColor = true;
            this.buttonDel1.Visible = false;
            this.buttonDel1.Click += new System.EventHandler(this.ButtonDel1_Click);
            // 
            // buttonDel2
            // 
            this.buttonDel2.Location = new System.Drawing.Point(0, 3);
            this.buttonDel2.Name = "buttonDel2";
            this.buttonDel2.Size = new System.Drawing.Size(75, 23);
            this.buttonDel2.TabIndex = 3;
            this.buttonDel2.Text = "LÖSCHEN";
            this.buttonDel2.UseVisualStyleBackColor = true;
            this.buttonDel2.Visible = false;
            this.buttonDel2.Click += new System.EventHandler(this.ButtonDel2_Click);
            // 
            // pictureBox1
            // 
            this.pictureBox1.BackColor = System.Drawing.SystemColors.Control;
            this.pictureBox1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.pictureBox1.Location = new System.Drawing.Point(0, 0);
            this.pictureBox1.Name = "pictureBox1";
            this.pictureBox1.Size = new System.Drawing.Size(480, 385);
            this.pictureBox1.SizeMode = System.Windows.Forms.PictureBoxSizeMode.Zoom;
            this.pictureBox1.TabIndex = 6;
            this.pictureBox1.TabStop = false;
            this.pictureBox1.Visible = false;
            this.pictureBox1.Click += new System.EventHandler(this.ButtonDel1_Click);
            // 
            // pictureBox2
            // 
            this.pictureBox2.BackColor = System.Drawing.SystemColors.Control;
            this.pictureBox2.Dock = System.Windows.Forms.DockStyle.Fill;
            this.pictureBox2.Location = new System.Drawing.Point(0, 0);
            this.pictureBox2.Name = "pictureBox2";
            this.pictureBox2.Size = new System.Drawing.Size(476, 385);
            this.pictureBox2.SizeMode = System.Windows.Forms.PictureBoxSizeMode.Zoom;
            this.pictureBox2.TabIndex = 7;
            this.pictureBox2.TabStop = false;
            this.pictureBox2.Visible = false;
            this.pictureBox2.Click += new System.EventHandler(this.ButtonDel2_Click);
            // 
            // buttonKeinDuplikat
            // 
            this.buttonKeinDuplikat.Anchor = System.Windows.Forms.AnchorStyles.Top;
            this.buttonKeinDuplikat.Location = new System.Drawing.Point(372, 12);
            this.buttonKeinDuplikat.Name = "buttonKeinDuplikat";
            this.buttonKeinDuplikat.Size = new System.Drawing.Size(217, 23);
            this.buttonKeinDuplikat.TabIndex = 8;
            this.buttonKeinDuplikat.Text = "KEIN DUPLIKAT";
            this.buttonKeinDuplikat.UseVisualStyleBackColor = true;
            this.buttonKeinDuplikat.Visible = false;
            this.buttonKeinDuplikat.Click += new System.EventHandler(this.ButtonKeinDuplikat_Click);
            // 
            // splitContainer1
            // 
            this.splitContainer1.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
            | System.Windows.Forms.AnchorStyles.Left) 
            | System.Windows.Forms.AnchorStyles.Right)));
            this.splitContainer1.Enabled = false;
            this.splitContainer1.Location = new System.Drawing.Point(12, 41);
            this.splitContainer1.Name = "splitContainer1";
            // 
            // splitContainer1.Panel1
            // 
            this.splitContainer1.Panel1.Controls.Add(this.pictureBox1);
            // 
            // splitContainer1.Panel2
            // 
            this.splitContainer1.Panel2.Controls.Add(this.pictureBox2);
            this.splitContainer1.Size = new System.Drawing.Size(960, 385);
            this.splitContainer1.SplitterDistance = 480;
            this.splitContainer1.TabIndex = 9;
            this.splitContainer1.KeyDown += new System.Windows.Forms.KeyEventHandler(this.Form1_KeyDown);
            // 
            // label3
            // 
            this.label3.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
            this.label3.Location = new System.Drawing.Point(782, 17);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(190, 23);
            this.label3.TabIndex = 10;
            this.label3.Text = "label3";
            this.label3.TextAlign = System.Drawing.ContentAlignment.TopRight;
            this.label3.Visible = false;
            // 
            // buttonReload
            // 
            this.buttonReload.Location = new System.Drawing.Point(93, 12);
            this.buttonReload.Name = "buttonReload";
            this.buttonReload.Size = new System.Drawing.Size(75, 23);
            this.buttonReload.TabIndex = 11;
            this.buttonReload.Text = "reload";
            this.buttonReload.UseVisualStyleBackColor = true;
            this.buttonReload.Click += new System.EventHandler(this.ButtonReload_Click);
            // 
            // splitContainer2
            // 
            this.splitContainer2.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left) 
            | System.Windows.Forms.AnchorStyles.Right)));
            this.splitContainer2.Location = new System.Drawing.Point(12, 429);
            this.splitContainer2.Name = "splitContainer2";
            // 
            // splitContainer2.Panel1
            // 
            this.splitContainer2.Panel1.Controls.Add(this.richTextBoxDesc1);
            this.splitContainer2.Panel1.Controls.Add(this.buttonDel1);
            // 
            // splitContainer2.Panel2
            // 
            this.splitContainer2.Panel2.Controls.Add(this.richTextBoxDesc2);
            this.splitContainer2.Panel2.Controls.Add(this.buttonDel2);
            this.splitContainer2.Size = new System.Drawing.Size(959, 115);
            this.splitContainer2.SplitterDistance = 480;
            this.splitContainer2.TabIndex = 12;
            this.splitContainer2.KeyDown += new System.Windows.Forms.KeyEventHandler(this.Form1_KeyDown);
            // 
            // buttonAPISetting
            // 
            this.buttonAPISetting.Location = new System.Drawing.Point(174, 12);
            this.buttonAPISetting.Name = "buttonAPISetting";
            this.buttonAPISetting.Size = new System.Drawing.Size(75, 23);
            this.buttonAPISetting.TabIndex = 13;
            this.buttonAPISetting.Text = "API Setting";
            this.buttonAPISetting.UseVisualStyleBackColor = true;
            this.buttonAPISetting.Click += new System.EventHandler(this.ButtonAPI_Click);
            // 
            // buttonAPILoad
            // 
            this.buttonAPILoad.Location = new System.Drawing.Point(255, 12);
            this.buttonAPILoad.Name = "buttonAPILoad";
            this.buttonAPILoad.Size = new System.Drawing.Size(75, 23);
            this.buttonAPILoad.TabIndex = 14;
            this.buttonAPILoad.Text = "Load API";
            this.buttonAPILoad.UseVisualStyleBackColor = true;
            this.buttonAPILoad.Click += new System.EventHandler(this.ButtonAPILoad_Click);
            // 
            // richTextBoxDesc1
            // 
            this.richTextBoxDesc1.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
            | System.Windows.Forms.AnchorStyles.Left) 
            | System.Windows.Forms.AnchorStyles.Right)));
            this.richTextBoxDesc1.BackColor = System.Drawing.SystemColors.Control;
            this.richTextBoxDesc1.BorderStyle = System.Windows.Forms.BorderStyle.None;
            this.richTextBoxDesc1.Location = new System.Drawing.Point(3, 32);
            this.richTextBoxDesc1.Name = "richTextBoxDesc1";
            this.richTextBoxDesc1.ReadOnly = true;
            this.richTextBoxDesc1.ScrollBars = System.Windows.Forms.RichTextBoxScrollBars.None;
            this.richTextBoxDesc1.Size = new System.Drawing.Size(474, 78);
            this.richTextBoxDesc1.TabIndex = 4;
            this.richTextBoxDesc1.Text = "";
            this.richTextBoxDesc1.Visible = false;
            // 
            // richTextBoxDesc2
            // 
            this.richTextBoxDesc2.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
            | System.Windows.Forms.AnchorStyles.Left) 
            | System.Windows.Forms.AnchorStyles.Right)));
            this.richTextBoxDesc2.BorderStyle = System.Windows.Forms.BorderStyle.None;
            this.richTextBoxDesc2.Location = new System.Drawing.Point(0, 32);
            this.richTextBoxDesc2.Name = "richTextBoxDesc2";
            this.richTextBoxDesc2.ReadOnly = true;
            this.richTextBoxDesc2.ScrollBars = System.Windows.Forms.RichTextBoxScrollBars.None;
            this.richTextBoxDesc2.Size = new System.Drawing.Size(469, 78);
            this.richTextBoxDesc2.TabIndex = 5;
            this.richTextBoxDesc2.Text = "";
            this.richTextBoxDesc2.Visible = false;
            // 
            // Main
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.ClientSize = new System.Drawing.Size(984, 551);
            this.Controls.Add(this.buttonAPILoad);
            this.Controls.Add(this.buttonAPISetting);
            this.Controls.Add(this.splitContainer2);
            this.Controls.Add(this.buttonReload);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.splitContainer1);
            this.Controls.Add(this.buttonKeinDuplikat);
            this.Controls.Add(this.buttonCSV);
            this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
            this.KeyPreview = true;
            this.MinimumSize = new System.Drawing.Size(1000, 590);
            this.Name = "Main";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Bildduplikate v1.5 by kmpr.at";
            this.FormClosing += new System.Windows.Forms.FormClosingEventHandler(this.Main_FormClosing);
            this.Shown += new System.EventHandler(this.Main_Shown);
            this.KeyDown += new System.Windows.Forms.KeyEventHandler(this.Form1_KeyDown);
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox2)).EndInit();
            this.splitContainer1.Panel1.ResumeLayout(false);
            this.splitContainer1.Panel2.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.splitContainer1)).EndInit();
            this.splitContainer1.ResumeLayout(false);
            this.splitContainer2.Panel1.ResumeLayout(false);
            this.splitContainer2.Panel2.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.splitContainer2)).EndInit();
            this.splitContainer2.ResumeLayout(false);
            this.ResumeLayout(false);

        }

        #endregion

        private System.Windows.Forms.Button buttonCSV;
        private System.Windows.Forms.Button buttonDel1;
        private System.Windows.Forms.Button buttonDel2;
        private System.Windows.Forms.PictureBox pictureBox1;
        private System.Windows.Forms.PictureBox pictureBox2;
        private System.Windows.Forms.Button buttonKeinDuplikat;
        private System.Windows.Forms.OpenFileDialog openFileDialog1;
        private System.Windows.Forms.SplitContainer splitContainer1;
        private System.Windows.Forms.Label label3;
        private System.Windows.Forms.Button buttonReload;
        private System.Windows.Forms.SplitContainer splitContainer2;
        private System.Windows.Forms.Button buttonAPISetting;
        private System.Windows.Forms.Button buttonAPILoad;
        private System.Windows.Forms.RichTextBox richTextBoxDesc1;
        private System.Windows.Forms.RichTextBox richTextBoxDesc2;
    }
}
